.. module:: enaml.widgets.dock_pane

=======================
enaml.widgets.dock_pane
=======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    DockPane


.. autoclass:: DockPane
